#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.

import sys
import getopt
import getpass
import poplib
import string
import StringIO
import xml.sax

#import gantlet.config
from gantlet.session_email_parser import session_email_parser
from gantlet.session_archiver import session_archiver

help_string="""
HELP:

 -h   | --help                       Display this message
 -v   | --verbose                    Verbose
 -s<> | --pop-server=<>              <>=string, name of server (e.g. mail.llnl.gov)
 -u<> | --userid=<>                  <>=string, userid of mail account
 -p<> | --passwd=<>                  <>=string, password (not recommended)
 -r<> | --repository=<>              <>=string, path to where Gantlet msgs are stored
 -c   | --count                      Count total messages
 -d   | --delete                     Delele Gantlet msgs from server
 -j   | --delete-junk                Delete non Gantlet msgs from server
 
"""

class session_pop_client:
    """Pull gantlet messages from a Pop Server.

    This module provides a user interface for pulling
    Gantlet messages from a POP server and handing
    them off to the gantlet.file_manager.

    pop_client = session_pop_client( popserver, popuser, passwd ) # create client, but does not connect
    all_msgs = pop_client.load_msgs( ) # connect, get messages, disconnect
    (msgs, junk) = pop_client.split_msgs( all_msgs ) # sort messages

    messages are encapsulated as an array of session_email_parsers 
    
    """

    def __init__(self, popserver, popuser, passwd, debug=0):
        """Create instance based on server, userid, and passwd"""
        self.popserver = popserver
        self.popuser = popuser
        self.passwd = passwd
        self.connection = None
        self.debug = debug

    def connect(self):
        """Return live connection to the server"""
        if self.debug > 1: print 'Connecting...'
        server = poplib.POP3( self.popserver )
        server.user( self.popuser )
        server.pass_( self.passwd )
        if self.debug > 1: print server.getwelcome()
        return server
    
    def load_msgs( self, loadfrom=1 ):
        """Connect, load session_email_parser's into memory, and disconnect.

        A connection is attempted and all messages starting
        from 'loadfrom' (default=1) are put into a list of         
        gantlet.session_email_parser and returned.  The messages are NOT
        removed from the POP server in the process.

        """
        n_failed=0
        server = self.connect( )
        try:
            if self.debug > 1 : print server.list()
            msgs = []
            (n_msgs, bytes) = server.stat()
            if self.debug > 1 :
                print "Retrieving %d messages (%d bytes)" % ( n_msgs, bytes )
            for i in range( loadfrom, n_msgs+1 ):
                (hdr, content, bytes) = server.retr(i)
                content = string.join( content, '\n')            
                strfile = StringIO.StringIO(content)  # make string look like file
                try:
                    msg =  session_email_parser( strfile, i, content )
                    msgs.append(msg)
                except xml.sax._exceptions.SAXParseException:
                    print "Message %d had parse exception" %(i,)
                    n_failed = n_failed + 1
        finally:
            server.quit()
        assert len(msgs) == (n_msgs - loadfrom - n_failed + 1)
        return msgs 

    def del_msgs( self, msgs ):
        """Connect to POP server, delete msgs.id, and disconnect
        
        msgs - array of items with an integer 'id' attribute

        Messages are deleted on the basis of their id number
        matching on the POP server.  This is not a problem as
        long as another client doesn't delete the messages
        out from under you.

        """
        if len( msgs ) == 0 : return
        server = self.connect( )
        try:
            print server.list()
            for i in msgs:
                if self.debug > 1 :
                    print "deleting msg %d \"%s\"" % (i.id, i.subject)
                server.dele(i.id)
        finally:
            server.quit()

    def split_msgs( self, msgs ):
        """Sort messages between gantlet msgs and chaff.

        Gantlet messages have an 'is_gantlet' attribute
        that evaluates to true
        """
        valid_msgs = []
        invalid_msgs = []
        for i in msgs:
            if i.is_gantlet:
                valid_msgs.append(i)
            else:
                invalid_msgs.append(i)
        return ( valid_msgs, invalid_msgs )
        

def _commandline():
    popserver=None
    popuser=None
    passwd = None
    delete_junk = None
    delete_msgs = None
    count = None
    repository = None
    verbose = None
    shortopts = "hvs:u:p:r:cdj"
    longopts = ["help", "verbose" "pop-server=", "userid=", "passwd=", "repository=",
                "count", "delete", "delete-junk" ]

    (opts,args) = getopt.getopt( sys.argv[1:], shortopts, longopts )
    for (o, v) in opts:
        if o in ("-h", "--help"):
            print help_string
            sys.exit(0)
        elif o in ("-v", "--verbose"):
            verbose = 1
        elif o in ("-s", "--pop-server"):
            popserver = v
        elif o in ("-u", "--userid"):
            popuser = v
        elif o in ("-p", "--passwd"):
            passwd = v
        elif o in ("-r", "--repository"):
            repository = v
        elif o in ("-c", "--count"):
            count = 1
        elif o in ( "-d", "--delete" ):
            delete_msgs = 1
        elif o in ("-j", "--delete-junk"):
            delete_junk = 1
            
    if not passwd:
        passwd = getpass.getpass( "Password for %s@%s : " % (popuser, popserver) )

    # Now do the interesting stuff
    mail_reader = session_pop_client( popserver, popuser, passwd, debug=3 )
    all_msgs = mail_reader.load_msgs( )
    (msgs, junk) = mail_reader.split_msgs( all_msgs )
    
    if count or verbose :
        print "%d messages total:  %d gantlet, %d other" % (

            len( all_msgs), len( msgs ), len (junk ) )

    if verbose:
        for msg in msgs:
            #print (msg.id, msg.attr)
            if '/' in msg.attr['session']:
                print '*********************'
                msg.attr['session']='ask_epperly'
            else:
                print '**** NO RENAMING NECESSARY ****'
            print (msg.id, msg.attr)

    if repository and len(msgs):
        if verbose: print "Loading into repository ('%s')" % repository
        mgr = session_archiver(repository)
        for msg in msgs:
            mgr.insert( msg )
        mgr.store_index()

    if delete_junk and delete_msgs:
        mail_reader.del_msgs( all_msgs )
    elif delete_junk:
        mail_reader.del_msgs( junk )
    elif delete_msgs:
        mail_reader.del_msgs( msgs )

    if verbose: print 'Bye.'
    
if __name__ == '__main__': _commandline()




#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.

import gantlet
from gantlet.events import *

import sys
if sys.version_info[0] == 2 and sys.version_info[1] >= 2:
    from xml.sax.saxutils import escape, quoteattr
else:
    from xml.sax.saxutils import escape
    def quoteattr(s):
        return "\"" + escape(s) + "\""

class xml_tree:
    """
    A base class for XML entities.  This base class is only
    meant for printing out the XML file.  The xml_display
    recieves Gantlet events and builds this tree.  The final
    step in displaying the tree is simply printing it to a file.
    """
    def __init__( self, element_name, parent ):
        self.element_name = element_name
        self.parent = parent
        self.children = []
        if parent != None:
            parent.children.append( self )

    def printTree( self, file, tab, newline="\n" ):
        if len(self.children) == 0 :
            self.printPrefix( file, tab, "/" )
        else:
            if len( self.children ) == 1 and self.children[-1].isOneLine():
                newline = ""
                tab2=0
                incr=0
            else:
                newline = "\n"
                tab2=tab
                incr=4
            self.printPrefix(file, tab, "" )
            for i in self.children:
                file.write(newline)
                i.printTree( file, tab+incr, newline )
            file.write(newline)    
            self.printPostfix( file, tab2 )

    def isOneLine(self):
        "returns true if can be formatted to one line"
        return len(self.children)==0

    def printPrefix( self, file, tab, inline):
        file.write( "%*s<%s%s>" % ( tab, "", self.element_name, inline) )

    def printPostfix( self, file, tab ):
        file.write( "%*s</%s>" %( tab, "", self.element_name) )

    def depth(self):
        "return integer depth of tree, root=1"
        if self.parent:
            return 1 + self.parent.depth()
        else:
            return 1

    def path(self):
        "return string path of self to root"
        if self.parent:
            return self.element_name + "->" + self.parent.path()
        else:
            return self.element_name

class xml_gantlet( xml_tree ):
    def __init__( self ):
        xml_tree.__init__( self, "gantlet", None)

    def printPrefix( self, file, tab, inline):
        file.write( "%*s<%s version=%s%s>" % ( tab, "", self.element_name, \
                                                   quoteattr( gantlet.VERSION), inline) )

class xml_gantlet_head( xml_tree ):
    def __init__( self, parent ):
        xml_tree.__init__( self, "head", parent)

class xml_gantlet_body( xml_tree ):
    def __init__( self, parent ):
        xml_tree.__init__( self, "body", parent)

class xml_attribute( xml_tree ):
    def __init__( self, parent, key, value ):
        xml_tree.__init__( self, "attribute", parent )
        self.key = key
        self.value = value

    def printPrefix( self, file, tab, inline):
        file.write( "%*s<%s key=%s value=%s%s>" % ( tab, "", self.element_name, \
                                                            quoteattr( self.key ), \
                                                            quoteattr( self.value ), inline) )
        
class xml_gantlet_test ( xml_tree ) :
    def __init__( self, parent ):
        xml_tree.__init__( self, "test", parent )
        test = None

    def printPrefix( self, file, tab, inline ):
        start = "%*s<test number=%s name=%s result=%s type=%s nparts=%s%s>" \
                % ( tab, "", quoteattr("%d"%self.test.number), quoteattr(self.test.name), \
                    quoteattr(self.test.result), quoteattr(self.test.type), quoteattr("%d"%len(self.test.part)),\
                    inline)
        file.write( start )
       
class xml_part ( xml_tree ):
    def __init__( self, parent ):
        xml_tree.__init__( self, "part", parent )
        self.result = "FAIL"
        self.number = -1

    def printPrefix( self, file, tab, inline ):
        file.write("%*s<part number=%s result=%s%s>" % \
                   (tab, "", quoteattr("%d"%self.number), quoteattr(self.result), inline ))

class xml_error ( xml_tree ):
    def __init__( self, parent, canon ):
        xml_tree.__init__( self, "error", parent )
        self.canon = canon

    def printPrefix( self, file, tab, inline ):
        start = "%*s<error canon=%s%s>" \
                % ( tab, "", quoteattr(self.canon), inline)
        file.write( start )


class xml_warning ( xml_tree ):
    def __init__( self, parent, canon ):
        xml_tree.__init__( self, "warning", parent )
        self.canon = canon

    def printPrefix( self, file, tab, inline ):
        start = "%*s<warning canon=%s%s>" \
                % ( tab, "", quoteattr(self.canon), inline)
        file.write( start )

class xml_comment ( xml_tree ):
    def __init__( self, parent ):
        xml_tree.__init__( self, "comment", parent )

class xml_pcdata ( xml_tree ) :
    def __init__( self, parent, buffer='' ):
        self.buffer = buffer
        if len( parent.children ) and \
           isinstance( parent.children[-1], xml_pcdata ):
            parent.children[-1].buffer += buffer
            self = parent.children[-1]
        else:
            xml_tree.__init__( self, "PCDATA", parent )
            self.buffer = buffer

    def isOneLine(self):
        return self.buffer.strip().rfind('\n') == -1

    def printPrefix( self, file, tab, inline ):
        file.write( escape(self.buffer).strip() )

    def printPostfix( self, file, tab ):
        pass
    
class xml_display:
    def test_begin( self, test ):
        self.tests.append( xml_gantlet_test( self.body ) )
        self.current = self.tests[-1]
        # xml_pcdata( self.current, "depth = %d" % self.current.depth() )
        
    def test_end( self, test ):
        self.tests[-1].test = test
        self.current = self.body
        
    def part_begin( self, data ):
        test = data[0]
        number = data[1]
        self.parts.append(xml_part(self.tests[-1]))
        self.parts[-1].number = number
        self.current = self.parts[-1]
        # xml_pcdata( self.current, "depth = %d" % self.current.depth() )        

    def part_end( self, data ):
        test = data[0]
        number = data[1]
        self.parts[-1].result = test.part[-1].result
        self.current = self.tests[-1]

    def display_error( self, data ):
        test = data[0]
        msg = data[1]
        canon = data[2]
        error = xml_error( self.current, canon )
        xml_pcdata( error, msg )
        
    def display_warning( self, data ):
        test = data[0]
        msg = data[1]
        canon = data[2]
        warning = xml_warning( self.current, canon )
        xml_pcdata( warning, msg )

    def text( self, buffer ):
        xml_pcdata( self.current, buffer )

    def comment( self, buffer ):
        comment = xml_comment( self.current )
        xml_pcdata( comment, buffer )
        # xml_pcdata( comment, "depth = %d, path = %s" % (comment.depth(),comment.path() ) )
        
    def display_final( self, scoreboard ):
        elapsedtime = scoreboard.endtime - scoreboard.starttime
        xml_attribute( self.head, "package", scoreboard.package )
        xml_attribute( self.head, "profile", scoreboard.profile )
        xml_attribute( self.head, "session", scoreboard.session )
        xml_attribute( self.head, "date", scoreboard.date )
        xml_attribute( self.head, "date_text", scoreboard.date_text )
        xml_attribute( self.head, "time", scoreboard.shorttime )
        xml_attribute( self.head, "whoami", scoreboard.whoami )
        xml_attribute( self.head, "hostname", scoreboard.hostname )
        xml_attribute( self.head, "elapsedtime", "%g" % elapsedtime )
        xml_attribute( self.head, "total_tests", "%d" % scoreboard.tot_tests )
        xml_attribute( self.head, "passed_tests", "%d" % scoreboard.tot_tests_passed )
        xml_attribute( self.head, "xfailed_tests", "%d" % scoreboard.tot_tests_xfailed )
        xml_attribute( self.head, "failed_tests", "%d" % scoreboard.tot_tests_failed )
        xml_attribute( self.head, "broken_tests", "%d" % scoreboard.tot_tests_broken )
        xml_attribute( self.head, "total_parts", "%d" % scoreboard.tot_parts )
        xml_attribute( self.head, "passed_parts", "%d" % scoreboard.tot_parts_passed )
        xml_attribute( self.head, "xfailed_parts", "%d" % scoreboard.tot_parts_xfailed )
        xml_attribute( self.head, "failed_parts", "%d" % scoreboard.tot_parts_failed )
        
        self.gantlet.printTree( self.file, 0 )
        if self.closefile:
            self.file.close()
        return

    def __init__( self, scoreboard, file ):
        self.linewidth = scoreboard.config.linewidth - 10
        self.file = file
        self.tests = []
        self.parts = []
        self.buffer = ''
        self.gantlet = xml_gantlet()
        self.head = xml_gantlet_head( self.gantlet )
        self.body = xml_gantlet_body( self.gantlet )
        self.current = self.body # || self.test[-1] || self.part[-1]
        self.closefile = 1 # true if close file in display_final()

        scoreboard.event['test_begin'].subscribe(
            test_begin_event( self.test_begin ) )
        scoreboard.event['test_end'].subscribe(
            test_end_event( self.test_end ) )
        scoreboard.event['suite_finish'].subscribe(
            suite_finish_event( self.display_final ) )
        scoreboard.event['test_error'].subscribe(
            test_error_event( self.display_error ) )
        scoreboard.event['test_warning'].subscribe(
            test_warning_event( self.display_warning ) )
        scoreboard.event['text'].subscribe(text_event( self.text ) )
        scoreboard.event['comment'].subscribe( comment_event( self.comment ) )
        scoreboard.event['part_begin'].subscribe(
            part_begin_event( self.part_begin ) )
        scoreboard.event['part_end'].subscribe(
            part_end_event( self.part_end ) )
        







#
# File:          Basic_Impl.py
# Symbol:        Args.Basic-v1.0
# Symbol Type:   class
# Babel Version: 1.4.0 (Revision: 6563M trunk)
# Description:   Implementation of sidl class Args.Basic in Python.
# 
# WARNING: Automatically generated; changes will be lost
# 
#


# DO-NOT-DELETE splicer.begin(_initial)
# Insert-Code-Here {_initial} ()
# DO-NOT-DELETE splicer.end(_initial)

import Args.Basic
import sidl.BaseClass
import sidl.BaseInterface
import sidl.ClassInfo
import sidl.RuntimeException
import sidl.NotImplementedException

# DO-NOT-DELETE splicer.begin(_before_type)
import re
import string

import sidlPyArrays
if sidlPyArrays.type == "numpy":
  from numpy import zeros, float32
elif sidlPyArrays.type == "numeric":
  import Numeric
  zeros = Numeric.zeros
  float32 = Numeric.Float32

def toFloat(d):
  tmp = zeros((1,), float32)
  try:
    tmp[0] = d
  except AttributeError:
    # don't die!
    tmp[0] = d
  return float(tmp[0])
# DO-NOT-DELETE splicer.end(_before_type)

class Basic:

# All calls to sidl methods should use __IORself

# Normal Babel creation pases in an IORself. If IORself == None
# that means this Impl class is being constructed for native delegation
  def __init__(self, IORself = None):
    if (IORself == None):
      self.__IORself = Args.Basic.Basic(impl = self)
    else:
      self.__IORself = IORself
# DO-NOT-DELETE splicer.begin(__init__)
# Insert-Code-Here {__init__} ()
# DO-NOT-DELETE splicer.end(__init__)

# Returns the IORself (client stub) of the Impl, mainly for use
# with native delegation
  def _getStub(self):
    return self.__IORself

  def returnbackbool(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(returnbackbool)
    return 1
# DO-NOT-DELETE splicer.end(returnbackbool)

  def passinbool(self, b):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # bool b
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passinbool)
    return b
# DO-NOT-DELETE splicer.end(passinbool)

  def passoutbool(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, b)
    # bool _return
    # bool b
    #

# DO-NOT-DELETE splicer.begin(passoutbool)
    return (1, 1)
# DO-NOT-DELETE splicer.end(passoutbool)

  def passinoutbool(self, b):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # bool b
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, b)
    # bool _return
    # bool b
    #

# DO-NOT-DELETE splicer.begin(passinoutbool)
    return (1, not b)
# DO-NOT-DELETE splicer.end(passinoutbool)

  def passeverywherebool(self, b1, b3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # bool b1
    # bool b3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, b2, b3)
    # bool _return
    # bool b2
    # bool b3
    #

# DO-NOT-DELETE splicer.begin(passeverywherebool)
    return (b1, 1, not b3)
# DO-NOT-DELETE splicer.end(passeverywherebool)

  def returnbackchar(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # char _return
    #

# DO-NOT-DELETE splicer.begin(returnbackchar)
    return "3"
# DO-NOT-DELETE splicer.end(returnbackchar)

  def passinchar(self, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # char c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passinchar)
    return c == "3"
# DO-NOT-DELETE splicer.end(passinchar)

  def passoutchar(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c)
    # bool _return
    # char c
    #

# DO-NOT-DELETE splicer.begin(passoutchar)
    return (1, "3")
# DO-NOT-DELETE splicer.end(passoutchar)

  def passinoutchar(self, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # char c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c)
    # bool _return
    # char c
    #

# DO-NOT-DELETE splicer.begin(passinoutchar)
    if re.match("^[a-z]$", c):
      c = string.upper(c)
    else:
      if re.match("^[A-Z]$", c):
        c = string.lower(c)
      else:
        return (0, c)
    return (1, c)
# DO-NOT-DELETE splicer.end(passinoutchar)

  def passeverywherechar(self, c1, c3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # char c1
    # char c3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c2, c3)
    # char _return
    # char c2
    # char c3
    #

# DO-NOT-DELETE splicer.begin(passeverywherechar)
    if re.match("^[a-z]$", c3):
      c3 = string.upper(c3)
    else:
      if re.match("^[A-Z]$", c3):
        c3 = string.lower(c3)
    if (c1 == "3"):
      retval = "3"
    else:
      retval = 0
    return (retval, "3", c3)
# DO-NOT-DELETE splicer.end(passeverywherechar)

  def returnbackint(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # int _return
    #

# DO-NOT-DELETE splicer.begin(returnbackint)
    return 3
# DO-NOT-DELETE splicer.end(returnbackint)

  def passinint(self, i):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # int i
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passinint)
    return i == 3
# DO-NOT-DELETE splicer.end(passinint)

  def passoutint(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, i)
    # bool _return
    # int i
    #

# DO-NOT-DELETE splicer.begin(passoutint)
    return (1, 3)
# DO-NOT-DELETE splicer.end(passoutint)

  def passinoutint(self, i):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # int i
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, i)
    # bool _return
    # int i
    #

# DO-NOT-DELETE splicer.begin(passinoutint)
    return (1, -i)
# DO-NOT-DELETE splicer.end(passinoutint)

  def passeverywhereint(self, i1, i3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # int i1
    # int i3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, i2, i3)
    # int _return
    # int i2
    # int i3
    #

# DO-NOT-DELETE splicer.begin(passeverywhereint)
    if (i1 == 3):
      retval = 3
    else:
      retval = 0
    return (retval, 3, -i3)
# DO-NOT-DELETE splicer.end(passeverywhereint)

  def returnbacklong(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # long _return
    #

# DO-NOT-DELETE splicer.begin(returnbacklong)
    return 3l
# DO-NOT-DELETE splicer.end(returnbacklong)

  def passinlong(self, l):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # long l
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passinlong)
    return l == 3
# DO-NOT-DELETE splicer.end(passinlong)

  def passoutlong(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, l)
    # bool _return
    # long l
    #

# DO-NOT-DELETE splicer.begin(passoutlong)
    return (1, 3l)
# DO-NOT-DELETE splicer.end(passoutlong)

  def passinoutlong(self, l):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # long l
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, l)
    # bool _return
    # long l
    #

# DO-NOT-DELETE splicer.begin(passinoutlong)
    return (1, -l)
# DO-NOT-DELETE splicer.end(passinoutlong)

  def passeverywherelong(self, l1, l3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # long l1
    # long l3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, l2, l3)
    # long _return
    # long l2
    # long l3
    #

# DO-NOT-DELETE splicer.begin(passeverywherelong)
    if (l1 == 3):
      retval = 3l
    else:
      retval = 0l
    return (retval, 3l, -l3)
# DO-NOT-DELETE splicer.end(passeverywherelong)

  def returnbackfloat(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # float _return
    #

# DO-NOT-DELETE splicer.begin(returnbackfloat)
    return 3.1
# DO-NOT-DELETE splicer.end(returnbackfloat)

  def passinfloat(self, f):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # float f
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passinfloat)
    return f == toFloat(3.1)
# DO-NOT-DELETE splicer.end(passinfloat)

  def passoutfloat(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, f)
    # bool _return
    # float f
    #

# DO-NOT-DELETE splicer.begin(passoutfloat)
    return (1, 3.1)
# DO-NOT-DELETE splicer.end(passoutfloat)

  def passinoutfloat(self, f):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # float f
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, f)
    # bool _return
    # float f
    #

# DO-NOT-DELETE splicer.begin(passinoutfloat)
    return (1, -f)
# DO-NOT-DELETE splicer.end(passinoutfloat)

  def passeverywherefloat(self, f1, f3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # float f1
    # float f3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, f2, f3)
    # float _return
    # float f2
    # float f3
    #

# DO-NOT-DELETE splicer.begin(passeverywherefloat)
    if (f1 == toFloat(3.1)):
      retval = toFloat(3.1)
    else:
      retval = 0
    return (retval, 3.1, -f3)
# DO-NOT-DELETE splicer.end(passeverywherefloat)

  def returnbackdouble(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(returnbackdouble)
    return 3.14
# DO-NOT-DELETE splicer.end(returnbackdouble)

  def passindouble(self, d):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # double d
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passindouble)
    return d == 3.14
# DO-NOT-DELETE splicer.end(passindouble)

  def passoutdouble(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, d)
    # bool _return
    # double d
    #

# DO-NOT-DELETE splicer.begin(passoutdouble)
    return (1, 3.14)
# DO-NOT-DELETE splicer.end(passoutdouble)

  def passinoutdouble(self, d):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # double d
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, d)
    # bool _return
    # double d
    #

# DO-NOT-DELETE splicer.begin(passinoutdouble)
    return (1, -d)
# DO-NOT-DELETE splicer.end(passinoutdouble)

  def passeverywheredouble(self, d1, d3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # double d1
    # double d3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, d2, d3)
    # double _return
    # double d2
    # double d3
    #

# DO-NOT-DELETE splicer.begin(passeverywheredouble)
    if (d1 == 3.14):
      retval = 3.14
    else:
      retval = 0
    return (retval, 3.14, -d3)
# DO-NOT-DELETE splicer.end(passeverywheredouble)

  def returnbackfcomplex(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # fcomplex _return
    #

# DO-NOT-DELETE splicer.begin(returnbackfcomplex)
    return 3.1 + 3.1j
# DO-NOT-DELETE splicer.end(returnbackfcomplex)

  def passinfcomplex(self, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # fcomplex c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passinfcomplex)
    return c == (toFloat(3.1) + toFloat(3.1) * 1j)
# DO-NOT-DELETE splicer.end(passinfcomplex)

  def passoutfcomplex(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c)
    # bool _return
    # fcomplex c
    #

# DO-NOT-DELETE splicer.begin(passoutfcomplex)
    return (1, 3.1 + 3.1j)
# DO-NOT-DELETE splicer.end(passoutfcomplex)

  def passinoutfcomplex(self, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # fcomplex c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c)
    # bool _return
    # fcomplex c
    #

# DO-NOT-DELETE splicer.begin(passinoutfcomplex)
    c = c.real - 1j*c.imag
    return (1, c)
# DO-NOT-DELETE splicer.end(passinoutfcomplex)

  def passeverywherefcomplex(self, c1, c3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # fcomplex c1
    # fcomplex c3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c2, c3)
    # fcomplex _return
    # fcomplex c2
    # fcomplex c3
    #

# DO-NOT-DELETE splicer.begin(passeverywherefcomplex)
    c3 = c3.real - 1j*c3.imag
    if (c1 == (toFloat(3.1) + toFloat(3.1) * 1j)):
      return (c1, (3.1 + 3.1j), c3)
    else:
      return (0+0j, (3.1 + 3.1j), c3)
# DO-NOT-DELETE splicer.end(passeverywherefcomplex)

  def returnbackdcomplex(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # dcomplex _return
    #

# DO-NOT-DELETE splicer.begin(returnbackdcomplex)
    return 3.14 + 3.14j
# DO-NOT-DELETE splicer.end(returnbackdcomplex)

  def passindcomplex(self, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # dcomplex c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

# DO-NOT-DELETE splicer.begin(passindcomplex)
    return c == (3.14 + 3.14j)
# DO-NOT-DELETE splicer.end(passindcomplex)

  def passoutdcomplex(self):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c)
    # bool _return
    # dcomplex c
    #

# DO-NOT-DELETE splicer.begin(passoutdcomplex)
    return (1, 3.14 + 3.14j)
# DO-NOT-DELETE splicer.end(passoutdcomplex)

  def passinoutdcomplex(self, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # dcomplex c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c)
    # bool _return
    # dcomplex c
    #

# DO-NOT-DELETE splicer.begin(passinoutdcomplex)
    c = c.real - 1j*c.imag
    return (1, c)
# DO-NOT-DELETE splicer.end(passinoutdcomplex)

  def passeverywheredcomplex(self, c1, c3):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # dcomplex c1
    # dcomplex c3
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, c2, c3)
    # dcomplex _return
    # dcomplex c2
    # dcomplex c3
    #

# DO-NOT-DELETE splicer.begin(passeverywheredcomplex)
    c3 = c3.real - 1j*c3.imag
    if (c1 == (3.14 + 3.14j)):
      return (c1, (3.14 + 3.14j), c3)
    else:
      return (0+0j, (3.14 + 3.14j), c3)
# DO-NOT-DELETE splicer.end(passeverywheredcomplex)

# DO-NOT-DELETE splicer.begin(_final)
# Insert-Code-Here {_final} ()
# DO-NOT-DELETE splicer.end(_final)



#! /usr/bin/env python

from os import popen
from re import compile
import sys


def runTest(i, verbose):
    array = 0
    object = 0
    special = 0
    broken = 0
    fileregex = compile(r"^(.*/)?([^/]+)$")
    filecheck = fileregex.match(i)
    specialerrors = compile(r"^((babel: (array )?data type invariant failure .*)|(babel: Exception occurred.*))$")
    leakline = compile(r"^((babel: no (objects|arrays) leaked)|(babel: leaked (object|array) .* reference count -?\d+ \(type .*\)))$")
    if filecheck:
        directory = filecheck.group(1)
        file = filecheck.group(2)
        if verbose:
            print i
        if directory and (len(directory) > 0):
            run = popen("cd " + directory + " ; ./" + file + " 2>&1")
        else:
            run = popen("./" + file + " 2>&1")
        linecount = 0
        line = run.readline()
        while (line):
            match = leakline.match(line)
            if (match):
                if verbose:
                    print match.group(1)
                linecount = linecount + 1
                if match.group(5) == "object":
                    object = object + 1
                else:
                    if match.group(5) == "array":
                        array = array + 1
            match = specialerrors.match(line)
            if (match):
                if verbose:
                    print match.group(1)
                special = special + 1
            line = run.readline()
        if linecount == 0:
            if verbose:
                print "BROKEN TEST: No report"
            broken = broken + 1
        exitstatus = run.close()
        if exitstatus:
            if verbose:
                print "Program", i, "exited with status", exitstatus
            broken = broken + 1
    else:
        if verbose:
            print "Skipping ", i
    return (array, object, special, broken)

if __name__ == '__main__':
    totalarrayleaks = 0
    totalobjectleaks = 0
    totalspecialerrors = 0
    totalbroken = 0
    from getopt import getopt
    from time import asctime
    session = ""
    opts, pargs = getopt(sys.argv[1:], '', ['summary-only', 'session=', 'summary-file='])
    verbose = 1
    for i in opts:
        if i[0] == "--summary-only":
            verbose = None
        elif i[0] == "--session":
            session = i[1]
        elif i[0] == "--summary-file":
            sys.stdout = open(i[1],"w")
    for i in pargs:
        (array, object, special, broken) = runTest(i, verbose)
        totalarrayleaks += array
        totalobjectleaks += object
        totalspecialerrors += special
        totalbroken += broken
    print "Test summary:", asctime()
    if session:
        print "     Session:", session
    print "================================================================"
    print " Total arrays leaked: ", totalarrayleaks
    print "Total objects leaked: ", totalobjectleaks
    print "Total special errors: ", totalspecialerrors
    print "  Total broken tests: ", totalbroken



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.

"""
A module from the Gantlet Testing Framework
"""

import os
import select

from gts_tparser import gts_tparser

known_extensions = { '.py':'python',
                     '.pl':'perl',
                     '.sh':'/bin/sh'}

class gts_tparser_script(gts_tparser):
    """
    A GTS tparser specific to manipulating scripts
    """

    def __init__( self, invocation,  scoreboard):
	gts_tparser.__init__(self, invocation, scoreboard)
        self.switches = ""

    def get_type( self ):
        return "gts_tparser_script"

    def runtest( self ):
        dirname = self.invocation.dirname
        basename = self.invocation.basename
        extension = self.invocation.extension
        switches = self.invocation.switches
        arguments = self.invocation.arguments
        change_dir = ""
        

        if ( self.invocation.cd_to_file != None ):
            cd_to_file = self.invocation.cd_to_file
        else:
            cd_to_file = self.scoreboard.config.cd_to_file

        lang = self.extension_to_language(extension)
 
        if cd_to_file:
            if dirname != "" and dirname != ".":
                command = "cd %s; %s %s%s %s %s" % ( dirname, lang, basename, extension,
                                                    switches, arguments)
                tmpfile = "%s/%s.testresult"%( dirname, basename)
            else:
                command = "%s %s%s %s %s" % ( lang, basename, extension,
                                             switches, arguments)
                tmpfile = "./%s.testresult"%( basename)
        else:
            command = "%s %s/%s%s %s %s" % ( lang, dirname, basename, extension, switches, arguments )
            tmpfile = "%s/%s.testresult"%( dirname, basename)

        # print "command = \"%s\"" % command
        filehandle1 = os.popen(command, 'r')
        filehandle2 = os.tmpfile()
        filehandle3 = open( tmpfile, "w");
        for line in filehandle1.readlines():
            filehandle2.write( line )
            filehandle3.write( line )
        self.exit_status = filehandle1.close()
        if self.exit_status:
            self.exit_status = self.exit_status >> 8
        filehandle2.seek(0)
        self.collect_results( filehandle2 )
        filehandle2.close()
        filehandle3.close()

    def extension_to_language(self, ex ):
        if known_extensions.has_key(ex):
            lang = known_extensions[ex]
        else:
            lang = 'cat'
        return lang



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.
import os
import re
import string

import filesys

_hasno_equals = re.compile(r'^[^=]*$')
_have_gantlet_name = re.compile(r'\bGANTLET_NAME=(\S*)')
_have_gantlet_cd = re.compile(r'\bGANTLET_CD=(\S*)')
_have_gantlet_noflags = re.compile(r'\bGANTLET_NOFLAGS=(\S*)')
_in_backticks = re.compile(r'^`(.*)`$');

class test_invocation:
    """
    test_invocation: The encapsulation of an entire evocation of a test.

    Has the following member data:
    raw_string    - (string) the entire original string
    symbolic_name - (string) the assigned symbolic name
    envsettings   - (string) environment settings (from raw)
    arguments     - (string) arguments (from raw)
    filename      - (string) complete filename (from raw possibly with vpath)
    is_srcdir     - (boolean) true if file is in srcdir
    cd_to_file    - (boolean) true if we must cd to the file's directory before executing
    dirname       - (string) directory prefix of filename
    basename      - (string) basename (from filename)
    extension     - (string) extension (from filename)
    errmgs        - (string) error messages
    """

    def __init__( self, raw_string, srcdir, scoreboard ):
        self.errmsgs = []

        # assign raw string
        cmd = _in_backticks.search(raw_string);
        if cmd:
            self.raw_string = cmd.group(1)
            self.is_command = 1
        else:
            self.raw_string = raw_string 
            self.is_command = 0
            
        # split raw_string = [ENV1=val1 [...]] /some/file.ext [-arg1 [...]]
        tokens = self.raw_string.split()
        index=0
        for token in tokens:
            if ( _hasno_equals.match( token ) ):
                break
            else:
                index = index + 1

        # set some basic attributes
        self.switches = ""
        self.envsettings = string.join(tokens[:index]," ")
        self.filename = os.path.expandvars( tokens[index] )
        self.arguments = string.join(tokens[index+1:], " ")
        self.dirname = os.path.dirname( self.filename )
        (self.basename, self.extension) = \
                        os.path.splitext( os.path.basename( self.filename ))

        self.cd_to_file = 1
        
        self.symbolic_name = self.PVT_get_name()

        if not self.is_command:
            self.PVT_confirm_file( srcdir )

        self.PVT_check_cd()

        self.PVT_set_options( scoreboard )

    #
    # The following methods with the PVT_ prefix should be considered private methods
    #

    def PVT_get_name( self ):
        # symbolic_name = raw filename or GANTLET_NAME=<arg>
        gotname = _have_gantlet_name.search(self.raw_string)
        if gotname:  #okay set the name and remove the explicit set from the string
            return gotname.group(1)
        else:
            return self.filename


    def PVT_check_cd( self ):
        # symbolic_name = raw filename or GANTLET_CD=<arg>
        gotcd = _have_gantlet_cd.search(self.raw_string)
        if gotcd:  #okay set the name and remove the explicit set from the string
            if (gotcd.group(1)[0] in [ 'Y', 'y' ]):
                self.cd_to_file = 1
            else:
                self.cd_to_file = 0


    def PVT_confirm_file(self, srcdir):
        # now determine file's location
        isSrcdir = ''
        if ( os.path.isfile( self.filename ) ):
            self.is_srcdir = 0
        elif ( os.path.isfile( os.path.join( srcdir, self.filename ) ) ):
            self.is_srcdir = 1
            self.filename = os.path.normpath( os.path.join( srcdir, self.filename ) )
        else:
            file = os.path.basename( self.filename )
            path1 = os.path.dirname( file )
            path2 = os.path.dirname(  os.path.join( srcdir, file ) )
            errmsg = "file '%s' not found in \n\t\t'%s' or\n\t\t'%s'" % \
                     ( file, path1, path2 )
            self.errmsgs.append( (errmsg,"file not found") )

    def PVT_set_options( self, scoreboard ):
        """
        set addtional options to the commands
        """
        if  _have_gantlet_noflags.search(self.raw_string):
            return
        if ( scoreboard.config.switches != '' ):
            self.switches += ' ' + scoreboard.config.switches

        if ( scoreboard.config.name != '' ):
            self.switches += " --config=%s" % scoreboard.config.name

        if ( scoreboard.config.srcdir != os.curdir ):
            bindir = filesys.check_vpath_build(scoreboard.config,self.dirname)
            if ( bindir != os.curdir ):
                self.switches += " --bindir=%s" % bindir



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.
"""
This object represents the scoreboard of tests
"""

import os
import os.path
import sys
import time
import socket # to get hostname
import inspect
import ConfigParser

#import gantlet.config
from gantlet.tparser_factory import tparser_factory
from gantlet.events import *

_config_defaults = { 'verbose':0,
                     'srcdir':os.curdir,
                     'switches':'',
                     'name':'',
                     'profile':'(default)',
                     'environ':'',
                     'histfile':'',
                     'allow_exit_status_only':None,
                     'linewidth':80,
                     'warn_deprecated':1,
                     'quiet':0,
                     'gui':0,
                     'email':0,
                     'cd_to_file':1 }

class _empty :
    pass

class scoreboard :
    def __init__( self, session ):
        # init status of tests
        self.tot_parts               = 0
        self.tot_parts_passed        = 0
        self.tot_parts_xfailed       = 0
        self.tot_parts_failed        = 0
        self.tot_tests               = 0
        self.tot_tests_passed        = 0
        self.tot_tests_xfailed       = 0
        self.tot_tests_failed        = 0
        self.tot_tests_broken        = 0
        self.tests_outstanding       = 0
        self.starttime               = time.time()
        self.elapsedtime             = 0.0
        self.date_text               = time.strftime("%a, %d %b %Y")
        self.date                    = time.strftime("%Y-%m-%d")
        self.shorttime               = time.strftime("%H:%M:%S")
        # init configuration based information

        d = os.path.dirname( inspect.getabsfile(scoreboard))
        cfg = ConfigParser.ConfigParser(_config_defaults)
        cfg.read([ os.path.join(d,'gantlet.cfg'),
                   os.path.join(d,'gantlet.site.cfg'),
                   os.path.expanduser('~/.gantlet.cfg'),
                   os.path.join(os.curdir,'gantlet.cfg')])
        # cfg.write(sys.stdout)
        cfg_obj = _empty()
        optlist = cfg.options('GANTLET')
        boolargs = ['allow_exit_status_only', 'warn_deprecated', 'quiet',
                    'gui', 'cd_to_file']
        intargs = ['verbose', 'linewidth' ]
        val=None
        for o in optlist:
            val=cfg.get('GANTLET',o)
            if val=='None': val=None            
            setattr( cfg_obj, o, val)
        for o in boolargs:
            if o in optlist:
                val=cfg.getboolean('GANTLET',o)
                if val=='None': val=None
                setattr( cfg_obj, o, val )
        for o in intargs:
            if o in optlist:
                val=cfg.getint('GANTLET',o)
                if val=='None': val=None
                setattr( cfg_obj, o, val )
        self.package                 = ''
        self.profile                 = cfg_obj.profile
        self.session                 = session
        self.config                  = cfg_obj
        self._id_no                  = 0
        
        # find my login
        try:
            self.whoami = os.getlogin()
        except:
            self.whoami = 'unknown'           
        
        # find my host name
        self.hostname = socket.getfqdn()
        
        # find my host platform
        self.platform = sys.platform
        
        # prepare a list of tests
        self.tests = []

	# prepare a series of events
        
        self.event = { 
        "test_begin" : event_handler( test_begin_event ),
        "test_end" : event_handler( test_end_event ),
        "test_added" : event_handler( test_added_event ),
        "part_begin" :  event_handler( part_begin_event ),
        "part_end" :  event_handler( part_end_event ),
        "text" : event_handler( text_event ),
        "comment" : event_handler( comment_event ),
        "test_warning" : event_handler( test_warning_event ),
        "test_error" : event_handler( test_error_event ),
        "test_interrupt" : event_handler( test_interrupt_event ),
        "test_exitstatus" : event_handler( test_exitstatus_event ),
        "suite_finish": event_handler( suite_finish_event) }
        
        self.event["test_end"].subscribe(
            test_end_event( self.increment_count ) )

        self.event["test_added"].subscribe(
            test_added_event( self.increment_tests_outstanding ) )

    def get_id( self ):
        self._id_no = self._id_no + 1
        return self._id_no

    def increment_tests_outstanding( self, n_additional ):
        if n_additional > 0:            
            self.tests_outstanding += n_additional
        
    def increment_count( self, test ):
        self.tot_tests += 1
        self.tests_outstanding -= 1
        #print " %d / %d " % ( self.tot_tests, self.tot_tests + self.tests_outstanding )
        if test.result == 'PASS':
            self.tot_tests_passed += 1
        elif test.result == 'XFAIL':
            self.tot_tests_xfailed += 1
        elif test.result == 'FAIL':
            self.tot_tests_failed += 1
        elif test.result == 'BROKEN':
            self.tot_tests_broken += 1
        if test.result != 'BROKEN':
            self.tot_parts += test.n_parts
            self.tot_parts_passed += test.n_parts_passed
            self.tot_parts_xfailed += test.n_parts_xfailed
            self.tot_parts_failed += test.n_parts_failed
        self.tests.append( test )
        
    def finish( self ):
        self.endtime               = time.time()
        self.event["suite_finish"].publish( suite_finish_event, self )        





#
# File:          EmployeeArray_Impl.py
# Symbol:        objarg.EmployeeArray-v0.5
# Symbol Type:   class
# Babel Version: 1.4.0 (Revision: 6563M trunk)
# Description:   Implementation of sidl class objarg.EmployeeArray in Python.
# 
# WARNING: Automatically generated; changes will be lost
# 
#


"""This class manages a collection of employees.
"""

# DO-NOT-DELETE splicer.begin(_initial)
# Put your code here...
# DO-NOT-DELETE splicer.end(_initial)

import objarg.Employee
import objarg.EmployeeArray
import sidl.BaseClass
import sidl.BaseInterface
import sidl.ClassInfo
import sidl.RuntimeException
import sidl.NotImplementedException

# DO-NOT-DELETE splicer.begin(_before_type)
# Put your code here...
# DO-NOT-DELETE splicer.end(_before_type)

class EmployeeArray:
  """\
This class manages a collection of employees.
"""

# All calls to sidl methods should use __IORself

# Normal Babel creation pases in an IORself. If IORself == None
# that means this Impl class is being constructed for native delegation
  def __init__(self, IORself = None):
    if (IORself == None):
      self.__IORself = objarg.EmployeeArray.EmployeeArray(impl = self)
    else:
      self.__IORself = IORself
# DO-NOT-DELETE splicer.begin(__init__)
    self.employees = []
# DO-NOT-DELETE splicer.end(__init__)

# Returns the IORself (client stub) of the Impl, mainly for use
# with native delegation
  def _getStub(self):
    return self.__IORself

  def getLength(self):
    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # int _return
    #

    """\
Return the number of employees in the employee array.
"""
# DO-NOT-DELETE splicer.begin(getLength)
    return len(self.employees)
# DO-NOT-DELETE splicer.end(getLength)

  def at(self, index):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # int index
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # objarg.Employee _return
    #

    """\
Return the employee in position <code>index</code> where
<code>index</code> ranges from 1 to the length of the array.
If <code>index</code> is outside the range of the array (i.e.
less than or equal to zero or greater than the current number
of elements in the array), this method returns a NULL
employee object.
"""
# DO-NOT-DELETE splicer.begin(at)
    if (index >= 1 and index <= len(self.employees)):
        return self.employees[index-1]
    return None
# DO-NOT-DELETE splicer.end(at)

  def appendEmployee(self, e):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # objarg.Employee e
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # bool _return
    #

    """\
Add an employee onto the end of the array.  It is perfectly
legal to add the same employee multiple times.
<code>true</code> is returned when the append was successful;
otherwise, <code>false</code> is returned to indicate
failure.  This method will not add a NULL employee.
"""
# DO-NOT-DELETE splicer.begin(appendEmployee)
    if (e):
        self.employees.append(e)
        return 1
    return 0
# DO-NOT-DELETE splicer.end(appendEmployee)

  def findByName(self, name):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # string name
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, e)
    # int _return
    # objarg.Employee e
    #

    """\
Find the first employee in the array that has a name matching
<code>name</code>.  If a match exists, the index is returned,
and the employee is returned in parameter <code>e</code>.

If no match exists, 0 is returned, and <code>e</code> is NULL.
"""
# DO-NOT-DELETE splicer.begin(findByName)
    index = 1
    for e in self.employees:
        if (e.getName() == name):
            return index, e
        index = index + 1
    return 0, None
# DO-NOT-DELETE splicer.end(findByName)

  def promoteToMaxSalary(self, e):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # objarg.Employee e
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # (_return, e)
    # bool _return
    # objarg.Employee e
    #

    """\
Determine the maximum salary in the array. If the maximum
salary in the array is greater than the current salary of
<code>e</code>, the salary of <code>e</code> will be 
increased to the maximum salary in the array.  If the
array is empty, no change will be made to <code>e</code>.

This method returns <code>true</code> iff the salary of
<code>e</code> is modified.
"""
# DO-NOT-DELETE splicer.begin(promoteToMaxSalary)
    if (e):
      maxSalary = -1.0e37
      for i in self.employees:
        if (i.getSalary() > maxSalary):
          maxSalary = i.getSalary()
      if (maxSalary > e.getSalary()):
        e.setSalary(maxSalary)
        return 1, e
    return 0, e
# DO-NOT-DELETE splicer.end(promoteToMaxSalary)

# DO-NOT-DELETE splicer.begin(_final)
# Put your code here...
# DO-NOT-DELETE splicer.end(_final)



#
# File:          Test_Impl.py
# Symbol:        Overload.Test-v1.0
# Symbol Type:   class
# Babel Version: 1.4.0 (Revision: 6563M trunk)
# Description:   Implementation of sidl class Overload.Test in Python.
# 
# WARNING: Automatically generated; changes will be lost
# 
#


"""This class is used as the work-horse, returning the value passed
in.
"""

# DO-NOT-DELETE splicer.begin(_initial)
# Put your code here...
# DO-NOT-DELETE splicer.end(_initial)

import Overload.AClass
import Overload.AnException
import Overload.BClass
import Overload.ParentTest
import Overload.Test
import sidl.BaseClass
import sidl.BaseInterface
import sidl.ClassInfo
import sidl.RuntimeException
import sidl.NotImplementedException

# DO-NOT-DELETE splicer.begin(_before_type)
# Put your code here...
# DO-NOT-DELETE splicer.end(_before_type)

class Test:
  """\
This class is used as the work-horse, returning the value passed
in.
"""

# All calls to sidl methods should use __IORself

# Normal Babel creation pases in an IORself. If IORself == None
# that means this Impl class is being constructed for native delegation
  def __init__(self, IORself = None):
    if (IORself == None):
      self.__IORself = Overload.Test.Test(impl = self)
    else:
      self.__IORself = IORself
# DO-NOT-DELETE splicer.begin(__init__)
    # Put your code here...
# DO-NOT-DELETE splicer.end(__init__)

# Returns the IORself (client stub) of the Impl, mainly for use
# with native delegation
  def _getStub(self):
    return self.__IORself

  def getValueIntDouble(self, a, b):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # int a
    # double b
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueIntDouble)
    return a + b;
# DO-NOT-DELETE splicer.end(getValueIntDouble)

  def getValueDoubleInt(self, a, b):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # double a
    # int b
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueDoubleInt)
    return a + b;
# DO-NOT-DELETE splicer.end(getValueDoubleInt)

  def getValueIntDoubleFloat(self, a, b, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # int a
    # double b
    # float c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueIntDoubleFloat)
    return a + b + c;
# DO-NOT-DELETE splicer.end(getValueIntDoubleFloat)

  def getValueDoubleIntFloat(self, a, b, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # double a
    # int b
    # float c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueDoubleIntFloat)
    return a + b + c;
# DO-NOT-DELETE splicer.end(getValueDoubleIntFloat)

  def getValueIntFloatDouble(self, a, b, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # int a
    # float b
    # double c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueIntFloatDouble)
    return a + b + c;
# DO-NOT-DELETE splicer.end(getValueIntFloatDouble)

  def getValueDoubleFloatInt(self, a, b, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # double a
    # float b
    # int c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueDoubleFloatInt)
    return a + b + c;
# DO-NOT-DELETE splicer.end(getValueDoubleFloatInt)

  def getValueFloatIntDouble(self, a, b, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # float a
    # int b
    # double c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueFloatIntDouble)
    return a + b + c;
# DO-NOT-DELETE splicer.end(getValueFloatIntDouble)

  def getValueFloatDoubleInt(self, a, b, c):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # float a
    # double b
    # int c
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # double _return
    #

# DO-NOT-DELETE splicer.begin(getValueFloatDoubleInt)
    return a + b + c;
# DO-NOT-DELETE splicer.end(getValueFloatDoubleInt)

  def getValueException(self, v):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # Overload.AnException v
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # string _return
    #

# DO-NOT-DELETE splicer.begin(getValueException)
    return v.getNote();
# DO-NOT-DELETE splicer.end(getValueException)

  def getValueAClass(self, v):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # Overload.AClass v
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # int _return
    #

# DO-NOT-DELETE splicer.begin(getValueAClass)
    return v.getValue();
# DO-NOT-DELETE splicer.end(getValueAClass)

  def getValueBClass(self, v):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # Overload.BClass v
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # int _return
    #

# DO-NOT-DELETE splicer.begin(getValueBClass)
    return v.getValue();
# DO-NOT-DELETE splicer.end(getValueBClass)

# DO-NOT-DELETE splicer.begin(_final)
# Put your code here...
# DO-NOT-DELETE splicer.end(_final)



#! /usr/bin/env python
# Build file for Python modules
import sys
from re import compile
from distutils.core import setup, Extension

inc_re = compile('^--include-dirs=(.*)$')
lib_re = compile('^--library-dirs=(.*)$')
exlib_re = compile('^--extra-library=(.*)$')
old_argv = sys.argv
sys.argv = []
inc_dirs = ['.']
lib_dirs = []
libs = ['sidl']

for i in old_argv:
  m = inc_re.match(i)
  if (m):
    if (len(m.group(1))): inc_dirs.append(m.group(1))
  else:
    m = lib_re.match(i)
    if (m):
      if (len(m.group(1))): lib_dirs.append(m.group(1))
    else:
      m = exlib_re.match(i)
      if (m):
        if (len(m.group(1))): libs.append(m.group(1))
      else:
        sys.argv.append(i)
setup(name='llnl_babel_sidl_sidlx',
  include_dirs=inc_dirs,
  headers = [
    'sidl_BaseClass_Module.h',
    'sidl_BaseException_Module.h',
    'sidl_BaseInterface_Module.h',
    'sidl_CastException_Module.h',
    'sidl_ClassInfoI_Module.h',
    'sidl_ClassInfo_Module.h',
    'sidl_DFinder_Module.h',
    'sidl_DLL_Module.h',
    'sidl_EnfPolicy_Module.h',
    'sidl_Finder_Module.h',
    'sidl_InvViolation_Module.h',
    'sidl_LangSpecificException_Module.h',
    'sidl_Loader_Module.h',
    'sidl_MemAllocException_Module.h',
    'sidl_NotImplementedException_Module.h',
    'sidl_PostViolation_Module.h',
    'sidl_PreViolation_Module.h',
    'sidl_RuntimeException_Module.h',
    'sidl_SIDLException_Module.h',
    'sidl_io_Deserializer_Module.h',
    'sidl_io_IOException_Module.h',
    'sidl_io_Serializable_Module.h',
    'sidl_io_Serializer_Module.h',
    'sidl_rmi_BindException_Module.h',
    'sidl_rmi_Call_Module.h',
    'sidl_rmi_ConnectException_Module.h',
    'sidl_rmi_ConnectRegistry_Module.h',
    'sidl_rmi_InstanceHandle_Module.h',
    'sidl_rmi_InstanceRegistry_Module.h',
    'sidl_rmi_Invocation_Module.h',
    'sidl_rmi_MalformedURLException_Module.h',
    'sidl_rmi_NetworkException_Module.h',
    'sidl_rmi_NoRouteToHostException_Module.h',
    'sidl_rmi_NoServerException_Module.h',
    'sidl_rmi_ObjectDoesNotExistException_Module.h',
    'sidl_rmi_ProtocolException_Module.h',
    'sidl_rmi_ProtocolFactory_Module.h',
    'sidl_rmi_Response_Module.h',
    'sidl_rmi_Return_Module.h',
    'sidl_rmi_ServerInfo_Module.h',
    'sidl_rmi_ServerRegistry_Module.h',
    'sidl_rmi_TicketBook_Module.h',
    'sidl_rmi_Ticket_Module.h',
    'sidl_rmi_TimeOutException_Module.h',
    'sidl_rmi_UnexpectedCloseException_Module.h',
    'sidl_rmi_UnknownHostException_Module.h',
    'sidlx_rmi_BadFileDescriptorException_Module.h',
    'sidlx_rmi_ChildSocket_Module.h',
    'sidlx_rmi_ClientSocket_Module.h',
    'sidlx_rmi_Common_Module.h',
    'sidlx_rmi_ConnectionRefusedException_Module.h',
    'sidlx_rmi_ConnectionResetException_Module.h',
    'sidlx_rmi_GenNetworkException_Module.h',
    'sidlx_rmi_IPv4Socket_Module.h',
    'sidlx_rmi_JimEchoServer_Module.h',
    'sidlx_rmi_NetworkUnreachableException_Module.h',
    'sidlx_rmi_NoServerException_Module.h',
    'sidlx_rmi_NotEnoughMemoryException_Module.h',
    'sidlx_rmi_OutOfAddressesException_Module.h',
    'sidlx_rmi_RecoverableException_Module.h',
    'sidlx_rmi_RetryException_Module.h',
    'sidlx_rmi_ServerSocket_Module.h',
    'sidlx_rmi_Settings_Module.h',
    'sidlx_rmi_SimCall_Module.h',
    'sidlx_rmi_SimHandle_Module.h',
    'sidlx_rmi_SimReturn_Module.h',
    'sidlx_rmi_SimpleOrb_Module.h',
    'sidlx_rmi_SimpleServer_Module.h',
    'sidlx_rmi_SimpleTicketBook_Module.h',
    'sidlx_rmi_SimpleTicket_Module.h',
    'sidlx_rmi_Simsponse_Module.h',
    'sidlx_rmi_Simvocation_Module.h',
    'sidlx_rmi_Socket_Module.h',
    'sidlx_rmi_Statistics_Module.h',
    'sidlx_rmi_TimeoutException_Module.h',
    'sidlx_rmi_TooManyOpenFilesException_Module.h',
    'sidlx_rmi_UnauthorizedCallException_Module.h',
    'sidlx_rmi_UnexpectedCloseException_Module.h',
    'sidlx_rmi_UnrecognizedNetworkException_Module.h',
    'sidlx_rmi_UnrecoverableException_Module.h'
  ],
  packages = [
    'sidl',
    'sidl.io',
    'sidl.rmi',
    'sidlx',
    'sidlx.rmi'
  ],
  ext_modules = [
    Extension('sidl.BaseClass',
      ["sidl/sidl_BaseClass_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.BaseException',
      ["sidl/sidl_BaseException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.BaseInterface',
      ["sidl/sidl_BaseInterface_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.CastException',
      ["sidl/sidl_CastException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.ClassInfo',
      ["sidl/sidl_ClassInfo_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.ClassInfoI',
      ["sidl/sidl_ClassInfoI_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.DFinder',
      ["sidl/sidl_DFinder_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.DLL',
      ["sidl/sidl_DLL_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.EnfPolicy',
      ["sidl/sidl_EnfPolicy_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.Finder',
      ["sidl/sidl_Finder_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.InvViolation',
      ["sidl/sidl_InvViolation_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.LangSpecificException',
      ["sidl/sidl_LangSpecificException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.Loader',
      ["sidl/sidl_Loader_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.MemAllocException',
      ["sidl/sidl_MemAllocException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.NotImplementedException',
      ["sidl/sidl_NotImplementedException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.PostViolation',
      ["sidl/sidl_PostViolation_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.PreViolation',
      ["sidl/sidl_PreViolation_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.RuntimeException',
      ["sidl/sidl_RuntimeException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.SIDLException',
      ["sidl/sidl_SIDLException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.io.Deserializer',
      ["sidl/io/sidl_io_Deserializer_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.io.IOException',
      ["sidl/io/sidl_io_IOException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.io.Serializable',
      ["sidl/io/sidl_io_Serializable_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.io.Serializer',
      ["sidl/io/sidl_io_Serializer_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.BindException',
      ["sidl/rmi/sidl_rmi_BindException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.Call',
      ["sidl/rmi/sidl_rmi_Call_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.ConnectException',
      ["sidl/rmi/sidl_rmi_ConnectException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.ConnectRegistry',
      ["sidl/rmi/sidl_rmi_ConnectRegistry_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.InstanceHandle',
      ["sidl/rmi/sidl_rmi_InstanceHandle_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.InstanceRegistry',
      ["sidl/rmi/sidl_rmi_InstanceRegistry_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.Invocation',
      ["sidl/rmi/sidl_rmi_Invocation_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.MalformedURLException',
      ["sidl/rmi/sidl_rmi_MalformedURLException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.NetworkException',
      ["sidl/rmi/sidl_rmi_NetworkException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.NoRouteToHostException',
      ["sidl/rmi/sidl_rmi_NoRouteToHostException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.NoServerException',
      ["sidl/rmi/sidl_rmi_NoServerException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.ObjectDoesNotExistException',
      ["sidl/rmi/sidl_rmi_ObjectDoesNotExistException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.ProtocolException',
      ["sidl/rmi/sidl_rmi_ProtocolException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.ProtocolFactory',
      ["sidl/rmi/sidl_rmi_ProtocolFactory_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.Response',
      ["sidl/rmi/sidl_rmi_Response_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.Return',
      ["sidl/rmi/sidl_rmi_Return_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.ServerInfo',
      ["sidl/rmi/sidl_rmi_ServerInfo_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.ServerRegistry',
      ["sidl/rmi/sidl_rmi_ServerRegistry_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.Ticket',
      ["sidl/rmi/sidl_rmi_Ticket_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.TicketBook',
      ["sidl/rmi/sidl_rmi_TicketBook_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.TimeOutException',
      ["sidl/rmi/sidl_rmi_TimeOutException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.UnexpectedCloseException',
      ["sidl/rmi/sidl_rmi_UnexpectedCloseException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidl.rmi.UnknownHostException',
      ["sidl/rmi/sidl_rmi_UnknownHostException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.BadFileDescriptorException',
      ["sidlx/rmi/sidlx_rmi_BadFileDescriptorException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.ChildSocket',
      ["sidlx/rmi/sidlx_rmi_ChildSocket_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.ClientSocket',
      ["sidlx/rmi/sidlx_rmi_ClientSocket_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.Common',
      ["sidlx/rmi/sidlx_rmi_Common_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.ConnectionRefusedException',
      ["sidlx/rmi/sidlx_rmi_ConnectionRefusedException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.ConnectionResetException',
      ["sidlx/rmi/sidlx_rmi_ConnectionResetException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.GenNetworkException',
      ["sidlx/rmi/sidlx_rmi_GenNetworkException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.IPv4Socket',
      ["sidlx/rmi/sidlx_rmi_IPv4Socket_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.JimEchoServer',
      ["sidlx/rmi/sidlx_rmi_JimEchoServer_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.NetworkUnreachableException',
      ["sidlx/rmi/sidlx_rmi_NetworkUnreachableException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.NoServerException',
      ["sidlx/rmi/sidlx_rmi_NoServerException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.NotEnoughMemoryException',
      ["sidlx/rmi/sidlx_rmi_NotEnoughMemoryException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.OutOfAddressesException',
      ["sidlx/rmi/sidlx_rmi_OutOfAddressesException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.RecoverableException',
      ["sidlx/rmi/sidlx_rmi_RecoverableException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.RetryException',
      ["sidlx/rmi/sidlx_rmi_RetryException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.ServerSocket',
      ["sidlx/rmi/sidlx_rmi_ServerSocket_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.Settings',
      ["sidlx/rmi/sidlx_rmi_Settings_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.SimCall',
      ["sidlx/rmi/sidlx_rmi_SimCall_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.SimHandle',
      ["sidlx/rmi/sidlx_rmi_SimHandle_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.SimReturn',
      ["sidlx/rmi/sidlx_rmi_SimReturn_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.SimpleOrb',
      ["sidlx/rmi/sidlx_rmi_SimpleOrb_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.SimpleServer',
      ["sidlx/rmi/sidlx_rmi_SimpleServer_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.SimpleTicket',
      ["sidlx/rmi/sidlx_rmi_SimpleTicket_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.SimpleTicketBook',
      ["sidlx/rmi/sidlx_rmi_SimpleTicketBook_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.Simsponse',
      ["sidlx/rmi/sidlx_rmi_Simsponse_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.Simvocation',
      ["sidlx/rmi/sidlx_rmi_Simvocation_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.Socket',
      ["sidlx/rmi/sidlx_rmi_Socket_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.Statistics',
      ["sidlx/rmi/sidlx_rmi_Statistics_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.TimeoutException',
      ["sidlx/rmi/sidlx_rmi_TimeoutException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.TooManyOpenFilesException',
      ["sidlx/rmi/sidlx_rmi_TooManyOpenFilesException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.UnauthorizedCallException',
      ["sidlx/rmi/sidlx_rmi_UnauthorizedCallException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.UnexpectedCloseException',
      ["sidlx/rmi/sidlx_rmi_UnexpectedCloseException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.UnrecognizedNetworkException',
      ["sidlx/rmi/sidlx_rmi_UnrecognizedNetworkException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs),
    Extension('sidlx.rmi.UnrecoverableException',
      ["sidlx/rmi/sidlx_rmi_UnrecoverableException_Module.c"
      ],
      library_dirs=lib_dirs,
      libraries=libs)
  ])



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.

from gantlet.events import *

class debug_display:
    def display_test( self, test ):
        print "** Test %s, %d parts" % (test.name, test.nparts)

    def display_result( self, test ):
        print "** Result = %s (%d, %d, %d)" % (test.result,
        test.n_pass, test.n_xfail, test.n_fail)

    def display_part( self, test ):
        print "** part begin %d" % test.part[-1].number

    def display_partend( self, data ):
        test = data[0]
        resultno = data[1]
        print "** part end %d %s" % (resultno,test.part[-1].result)

    def display_warning( self, data ):
        test = data[0]
        msg = data[1]
        print "** WARNING: %s" % msg

    def display_error( self, data ):
        test = data[0]
        msg = data[1]
        print "** ERROR: %s" % msg


    def __init__( self, scoreboard ):
        scoreboard.event['test_begin'].subscribe(
            test_begin_event( self.display_test ) )
        scoreboard.event['test_end'].subscribe(
            test_end_event( self.display_result ) )
        # scoreboard.event['part_begin'].subscribe(
        #      part_begin_event( self.display_part ) )
        # scoreboard.event['part_end'].subscribe(
        #      part_end_event( self.display_partend ) )
        



#
# File:          IntOrderTest_Impl.py
# Symbol:        Ordering.IntOrderTest-v0.1
# Symbol Type:   class
# Babel Version: 1.4.0 (Revision: 6563M trunk)
# Description:   Implementation of sidl class Ordering.IntOrderTest in Python.
# 
# WARNING: Automatically generated; changes will be lost
# 
#


"""This class provides methods to verify that the array ordering
capabilities work for arrays of int.
"""

# DO-NOT-DELETE splicer.begin(_initial)
import sidlPyArrays
if sidlPyArrays.type == "numpy":
  from numpy import zeros, int32
elif sidlPyArrays.type == "numeric":
  import Numeric
  zeros = Numeric.zeros
  int32 = Numeric.Int32
# DO-NOT-DELETE splicer.end(_initial)

import Ordering.IntOrderTest
import sidl.BaseClass
import sidl.BaseInterface
import sidl.ClassInfo
import sidl.RuntimeException
import sidl.NotImplementedException

# DO-NOT-DELETE splicer.begin(_before_static)
def iFunc(ind):
  res = 0
  for i in range(len(ind)):
    res = res + (i+1) * ind[i]
  return res

def isIMatrix(A):
  if (len(A.shape) == 1):
    for i in range(A.shape[0]):
      if (A[i] != iFunc((i,))):
        return 0
  else:
    if (len(A.shape) == 2):
      for i in range(A.shape[0]):
        for j in range(A.shape[1]):
          if (A[i,j] != iFunc((i, j))):
              return 0
    else:
      if (len(A.shape) == 4):
        for i in range(A.shape[0]):
          for j in range(A.shape[1]):
            for k in range(A.shape[2]):
              for l in range(A.shape[3]):
                if (A[i,j,k,l] != iFunc((i, j, k, l))):
                    return 0
      else:
        return 0
  return 1
# DO-NOT-DELETE splicer.end(_before_static)

def makeColumnIMatrix(size, useCreateCol):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # int size
  # bool useCreateCol
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # array<int,2,column-major> _return
  #

  """\
Create a column-major matrix satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(makeColumnIMatrix)
  res = zeros((size, size), int32)
  for i in range(size):
    for j in range(size):
      res[i,j] = iFunc((i,j))
  return res
# DO-NOT-DELETE splicer.end(makeColumnIMatrix)

def makeRowIMatrix(size, useCreateRow):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # int size
  # bool useCreateRow
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # array<int,2,row-major> _return
  #

  """\
Create a row-major matrix satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(makeRowIMatrix)
  res = zeros((size, size), int32)
  for i in range(size):
    for j in range(size):
      res[i,j] = iFunc((i,j))
  return res
# DO-NOT-DELETE splicer.end(makeRowIMatrix)

def makeIMatrix(size, useCreateColumn):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # int size
  # bool useCreateColumn
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # array<int,4> _return
  #

  """\
Create a 4-D matrix satisfying condition I.  Each dimension has
size elements numbers 0 through size-1.
"""
# DO-NOT-DELETE splicer.begin(makeIMatrix)
  res = zeros((size, size, size, size), int32)
  for i in range(size):
    for j in range(size):
      for k in range(size):
        for l in range(size):
          res[i,j,k,l] = iFunc((i,j,k,l))
  return res
# DO-NOT-DELETE splicer.end(makeIMatrix)

def createColumnIMatrix(size, useCreateCol):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # int size
  # bool useCreateCol
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # array<int,2,column-major> res
  #

  """\
Create a column-major matrix satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(createColumnIMatrix)
  if (useCreateCol):
    return makeColumnIMatrix(size, 1)
  else:
    return makeRowIMatrix(size, 1)
# DO-NOT-DELETE splicer.end(createColumnIMatrix)

def createRowIMatrix(size, useCreateRow):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # int size
  # bool useCreateRow
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # array<int,2,row-major> res
  #

  """\
Create a row-major matrix satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(createRowIMatrix)
  if (useCreateRow):
    return makeRowIMatrix(size, 1)
  else:
    return makeColumnIMatrix(size, 1)
# DO-NOT-DELETE splicer.end(createRowIMatrix)

def ensureColumn(a):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,2,column-major> a
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # array<int,2,column-major> a
  #

  """\
Make sure an array is column-major.  No changes to the dimension or
values in a are made.
"""
# DO-NOT-DELETE splicer.begin(ensureColumn)
  return a
# DO-NOT-DELETE splicer.end(ensureColumn)

def ensureRow(a):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,2,row-major> a
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # array<int,2,row-major> a
  #

  """\
Make sure an array is row-major.  No changes to the dimension or
values in a are made.
"""
# DO-NOT-DELETE splicer.begin(ensureRow)
  return a
# DO-NOT-DELETE splicer.end(ensureRow)

def isIMatrixOne(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isIMatrixOne)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isIMatrixOne)

def isColumnIMatrixOne(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,column-major> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming column-major array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isColumnIMatrixOne)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isColumnIMatrixOne)

def isRowIMatrixOne(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,row-major> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming row-major array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isRowIMatrixOne)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isRowIMatrixOne)

def isIMatrixTwo(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,2> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isIMatrixTwo)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isIMatrixTwo)

def isColumnIMatrixTwo(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,2,column-major> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming column-major array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isColumnIMatrixTwo)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isColumnIMatrixTwo)

def isRowIMatrixTwo(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,2,row-major> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming row-major array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isRowIMatrixTwo)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isRowIMatrixTwo)

def isIMatrixFour(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,4> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isIMatrixFour)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isIMatrixFour)

def isColumnIMatrixFour(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,4,column-major> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming column-major array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isColumnIMatrixFour)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isColumnIMatrixFour)

def isRowIMatrixFour(A):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # array<int,4,row-major> A
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation sees
an incoming row-major array satisfying condition I.
"""
# DO-NOT-DELETE splicer.begin(isRowIMatrixFour)
  return isIMatrix(A)                 
# DO-NOT-DELETE splicer.end(isRowIMatrixFour)

def isSliceWorking(useCreateCol):
  #
  # sidl EXPECTED INCOMING TYPES
  # ============================
  # bool useCreateCol
  #

  #
  # sidl EXPECTED RETURN VALUE(s)
  # =============================
  # bool _return
  #

  """\
Return <code>true</code> iff the implementation of slice
and smart copy is correct.
"""
# DO-NOT-DELETE splicer.begin(isSliceWorking)
  return 1
# DO-NOT-DELETE splicer.end(isSliceWorking)

# DO-NOT-DELETE splicer.begin(_before_type)
# Put your code here...
# DO-NOT-DELETE splicer.end(_before_type)

class IntOrderTest:
  """\
This class provides methods to verify that the array ordering
capabilities work for arrays of int.
"""

# All calls to sidl methods should use __IORself

# Normal Babel creation pases in an IORself. If IORself == None
# that means this Impl class is being constructed for native delegation
  def __init__(self, IORself = None):
    if (IORself == None):
      self.__IORself = Ordering.IntOrderTest.IntOrderTest(impl = self)
    else:
      self.__IORself = IORself
# DO-NOT-DELETE splicer.begin(__init__)
    # Put your code here...
# DO-NOT-DELETE splicer.end(__init__)

# Returns the IORself (client stub) of the Impl, mainly for use
# with native delegation
  def _getStub(self):
    return self.__IORself

# DO-NOT-DELETE splicer.begin(_final)
# Put your code here...
# DO-NOT-DELETE splicer.end(_final)



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.
"""
Gantlet:  A Minimal Package for Testing software
"""

#__all__ = [ "scoreboard", "events", "commandline", "tparser_factory", "classic_display" ]

VERSION = "0.9.1"

CVS_VERSION="$Id: __init__.py 6171 2007-10-08 23:39:28Z epperly $"

AUTHORS="""
----------------------------------------------------------------------
  Gary Kumfert, Ph.D.                              <kumfert@llnl.gov>
  Center for Applied Scientific Computing          phone: 925-424-2580
  Lawrence Livermore National Laboratory           fax:   925-424-2477
  P.O. Box 808,    L-661
  Livermore, CA 94551-0808
----------------------------------------------------------------------  
"""

COPYRIGHT ="""
Copyright Notice
----------------

(c) 2001-2003 by Lawrence Livermore National Security, LLC.
All rights reserved.
Reference: UCRL-CODE-2002-043.

This work was produced at the University of California, Lawrence Livermore
National Laboratory (UC LLNL) under contract no. W-7405-ENG-48 (Contract 48)
between the U.S. Department of Energy (DOE) and The Regents of the University
of California (University) for the operation of UC LLNL. The rights of the
Federal Government are reserved under Contract 48 subject to the restrictions
agreed upon by the DOE and University as allowed under DOE Acquisition Letter
97-1.
"""

DISCLAIMER = """

Disclaimer
----------
 
This work was prepared as an account of work sponsored by an agency of
the United States Government. Neither the United States Government nor
the University of California nor any of their employees, makes any warranty,
express or implied, or assumes any liability or responsibility for the
accuracy, completeness, or usefulness of any information, apparatus, product,
or process disclosed, or represents that its use would not infringe privately-
owned rights.  Reference herein to any specific commercial products, process,
or service by trade name, trademark, manufacturer or otherwise does not
necessarily constitute or imply its endorsement, recommendation, or favoring
by the United States Government or the University of California. The views
and opinions of authors expressed herein do not necessarily state or reflect
those of the United States Government or the University of California, and
shall not be used for advertising or product endorsement purposes.
"""



#
# File:          User_Impl.py
# Symbol:        wrapper.User-v1.0
# Symbol Type:   class
# Babel Version: 1.4.0 (Revision: 6561M trunk)
# Description:   Implementation of sidl class wrapper.User in Python.
# 
# WARNING: Automatically generated; changes will be lost
# 
#


# DO-NOT-DELETE splicer.begin(_initial)
# Insert-Code-Here {_initial} ()
# DO-NOT-DELETE splicer.end(_initial)

import sidl.BaseClass
import sidl.BaseInterface
import sidl.ClassInfo
import sidl.RuntimeException
import wrapper.Data
import wrapper.User
import sidl.NotImplementedException

# DO-NOT-DELETE splicer.begin(_before_type)
# Insert-Code-Here {_before_type} ()
# DO-NOT-DELETE splicer.end(_before_type)

class User:

# All calls to sidl methods should use __IORself

# Normal Babel creation pases in an IORself. If IORself == None
# that means this Impl class is being constructed for native delegation
  def __init__(self, IORself = None):
    if (IORself == None):
      self.__IORself = wrapper.User.User(impl = self)
    else:
      self.__IORself = IORself
# DO-NOT-DELETE splicer.begin(__init__)
    # Insert-Code-Here {__init__} ()
# DO-NOT-DELETE splicer.end(__init__)

# Returns the IORself (client stub) of the Impl, mainly for use
# with native delegation
  def _getStub(self):
    return self.__IORself

  def accept(self, data):
    #
    # sidl EXPECTED INCOMING TYPES
    # ============================
    # wrapper.Data data
    #

    #
    # sidl EXPECTED RETURN VALUE(s)
    # =============================
    # None
    #

# DO-NOT-DELETE splicer.begin(accept)
    # Insert-Code-Here {accept} ()
    data.setString("Hello World!")
    data.setInt(3)
# DO-NOT-DELETE splicer.end(accept)

# DO-NOT-DELETE splicer.begin(_final)
# Insert-Code-Here {_final} ()
# DO-NOT-DELETE splicer.end(_final)



#
# File:  sidlBaseException.py
# Copyright (c) 2005 Lawrence Livermore National Security, LLC
# $Revision$
# $Date$
#

class sidlBaseException(Exception):
    """Base class for all SIDL Exception classes"""

    def __init__(self, exception):
        self.exception = exception



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.
from gantlet.events import *
_have_gui=1
try:
    from Tkinter import * 
    from gantlet.ProgressMeter import ProgressMeter
except:
    _have_gui=0
import gantlet

class gui_display :

    def update_ratio( self ):
        if self.scoreboard.tests_outstanding < 0:
            print "Ugh!"
            self.scoreboard.tests_outstanding = 0
        newtext = "%d/%d" % ( self.scoreboard.tot_tests, self.scoreboard.tot_tests + \
                              self.scoreboard.tests_outstanding )
        self.ratio.config(text=newtext)

    def test_begin( self, test ):
        self.filename.config(text=test.name)
        self.update_ratio()
        self.root.update()

    def add_test( self, n_new_tests ):
        self.meter.newMaximum( self.meter.max + n_new_tests )
        self.update_ratio()        
        
    def finish_test( self, test ):
        self.meter.add( 1 )
        self.tests_total.config(text=self.scoreboard.tot_tests)
        self.tests_passed.config(text=self.scoreboard.tot_tests_passed)
        self.tests_xfailed.config(text=self.scoreboard.tot_tests_xfailed)
        self.tests_failed.config(text=self.scoreboard.tot_tests_failed)
        self.tests_broken.config(text=self.scoreboard.tot_tests_broken)
        self.parts_total.config(text=self.scoreboard.tot_parts)
        self.parts_passed.config(text=self.scoreboard.tot_parts_passed)
        self.parts_xfailed.config(text=self.scoreboard.tot_parts_xfailed)
        self.parts_failed.config(text=self.scoreboard.tot_parts_failed)

    def finalize( self, scoreboard ):
        self.filename.config(text="Tests Completed.")
        self.update_ratio()
        self.root.update()

    def __init__( self, scoreboard ):
        self.scoreboard = scoreboard
        if not _have_gui:
            return
        self.root = Tk()

        # row 1
        f = Frame( self.root )
        f.master.title("Gantlet %s" % gantlet.VERSION)
        f.pack(side=TOP, expand=NO, fill=X)
        l = Label( f, text="File:", width=10, justify=RIGHT)
        l.pack(side=LEFT, expand=NO, fill=X)
        self.ratio = Label(f, width=10)
        self.ratio.pack(side=RIGHT, expand=NO )
        self.filename = Label( f, relief=SUNKEN, width=60, justify=LEFT)
        self.filename.pack(side=RIGHT, expand=YES, fill=X )

        # row 2
        f = Frame( self.root )
        f.pack(side=TOP, expand=NO, fill=X)
        l = Label(f, text="Progress:", width=10, justify=RIGHT)        
        l.pack(side=LEFT, expand=NO, fill=X)
        self.meter = ProgressMeter(f, max=scoreboard.tests_outstanding, fgcolor='#aaf')
        self.meter.pack(side=RIGHT, expand=YES, fill=X)

        # row 3
        f = Frame( self.root )
        f.pack(side=TOP, expand=NO, fill=X )
        l = Label(f,text="Stats:", width=10, justify=RIGHT)
        l.pack(side=LEFT, expand=NO, fill=X )
        f = Frame( f, relief=GROOVE, bd=5)
        f.pack(side=TOP, expand=YES, fill=BOTH)
        Label( f, text="Total" , width=10).grid(row=0, column=1)
        Label( f, text="Pass"  , width=10).grid(row=0, column=2)
        Label( f, text="Xfail" , width=10).grid(row=0, column=3)
        Label( f, text="Fail"  , width=10).grid(row=0, column=4)
        Label( f, text="Broken", width=10).grid(row=0, column=5)
        Label( f, text="Tests" ).grid(row=1, column=0)
        self.tests_total   = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#000" )
        self.tests_passed  = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#0a0" )
        self.tests_xfailed = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#990" )
        self.tests_failed  = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#a00" )
        self.tests_broken  = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#a00" )
        self.tests_total.grid(row=1,column=1)
        self.tests_passed.grid(row=1,column=2)
        self.tests_xfailed.grid(row=1,column=3)
        self.tests_failed.grid(row=1,column=4)
        self.tests_broken.grid(row=1,column=5)
        Label( f, text="Parts" ).grid(row=2, column=0)
        self.parts_total   = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#000" )
        self.parts_passed  = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#0a0" )
        self.parts_xfailed = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#990" )
        self.parts_failed  = Label( f, relief=SUNKEN, width=10, justify=RIGHT, fg="#a00" )
        self.parts_total.grid(row=2,column=1)
        self.parts_passed.grid(row=2,column=2)
        self.parts_xfailed.grid(row=2,column=3)
        self.parts_failed.grid(row=2,column=4)
        
        Button(self.root, text='Quit', command=self.root.quit ).pack()        
        
        scoreboard.event['test_begin'].subscribe(
            test_begin_event( self.test_begin ) )
        scoreboard.event['test_added'].subscribe(
            test_added_event( self.add_test ) )
        scoreboard.event['test_end'].subscribe(
            test_end_event( self.finish_test ) )
        scoreboard.event['suite_finish'].subscribe(
            suite_finish_event( self.finalize ) )



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.
import re
import string
import sys

import gantlet.events
from gantlet.tparser_base import tparser_base
from gantlet.gts_result import gts_result
from gantlet.exit_status_result import exit_status_result

_old_compound_begin = re.compile(r'^\s?TEST_BEGIN\s+(?P<testname>\D\S*)')
_old_test_begin = re.compile(r'^\s?NPARTS\s+(?P<nparts>[0-9\-]+)')
_test_begin = re.compile(r'^\s?(TEST_BEGIN|NPARTS)\s+(?P<nparts>[0-9\-]+)\s*(?P<testname>\S*)')
_test_end = re.compile(r'^\s?TEST_RESULT\s+(?P<result>PASS|FAIL|XFAIL|BROKEN)\s*(?P<exitstatus>\d*)')
_part_begin = re.compile(r'^\s?PART\s+(?P<partno>\d+)')
_part_end = re.compile(r'^\s?RESULT\s+(?P<partno>\d+)\s+(?P<result>PASS|XFAIL|UNTESTED|UNSUPPORTED|FAIL|XPASS|UNRESOLVED)')
_comment = re.compile(r'^\s?COMMENT\:\s+(?P<text>.*)')

class gts_tparser( tparser_base ):
    """
    This is the base class for all Gantlet Testing Syntax (GTS) tests
    """
   
    def __init__( self, invocation, scoreboard ):
        tparser_base.__init__(self, invocation, scoreboard )
        self.results = []   # list of tests
        self.buffer = []  # array of text strings
        self.comment_buffer = [] # array of text strings

    def get_type(self):
        return "gts_tparser"
        
    def collect_results(self, filehandle):
        # state = 'old compound begin' ||
        #         'before tests'  ||
        #         'between tests' ||
        #         'before parts'  ||
        #         'between parts'
        #         'in part'
        state = 'before tests'
        nparts = 0
        partno = 0
        resultno = 0
        compound_name = None
        lineno = 0
	try:
            while filehandle != None:
                loc = filehandle.tell()
                line = filehandle.readline()
                lineno = lineno + 1
                if line=='':
                    break
                # iterate over regex engines looking for a match
                old_test_begin = _old_test_begin.search(line)
                old_compound_begin = _old_compound_begin.search(line)
                test_begin = _test_begin.search(line)
                test_end = _test_end.search(line)
                part_begin = _part_begin.search(line)
                part_end = _part_end.search(line)
                if old_compound_begin and (not test_begin):
                    compound_name = old_compound_begin.group('testname')
                    self.PVT_flush_buffers()
                    state = 'old compound begin'
                elif old_test_begin:
                    if state not in ['old compound begin', 'before tests', 'between tests']:
                        print "Error: old-style test begin found in state=\"%s\"" %(state,)
                        print "   line %d=\"%s\"" %(lineno,line)
                    self.PVT_flush_buffers()
                    if state == 'old compound begin':
                        old_test_begin = _test_begin.search( "TEST_BEGIN %s %s" %
                                                             (old_test_begin.group('nparts'),
                                                              compound_name))
                        compound_name=None
                        state="between tests"
                    else:
                        state="before tests"
                    # now create new test
                    self.results.append( gts_result( self.invocation.symbolic_name,
                                                       self.scoreboard, self.get_type() ))
                    if len( self.results ) > 1:
                        self.scoreboard.event['test_added'].publish(gantlet.events.test_added_event, 1)
                    self.results[-1].exit_status = self.exit_status
                    state = self.results[-1].test_begin( state, old_test_begin )
                    if self.scoreboard.config.warn_deprecated :
                        self.results[-1].warning( "Old-style test beginning (deprecated)", "")
                elif test_begin:
                    if state not in ['before tests', 'between tests']:
                        print "Error: test begin found in state=\"%s\"" %(state,)
                        print "   line %d=\"%s\"" %(lineno,line)
                    self.PVT_flush_buffers()
                    self.results.append( gts_result( self.invocation.symbolic_name,
                                                       self.scoreboard, self.get_type() ))
                    if len( self.results ) > 1:
                        self.scoreboard.event['test_added'].publish(gantlet.events.test_added_event, 1)
                    self.results[-1].exit_status = self.exit_status
                    state = self.results[-1].test_begin( state, test_begin )
                elif part_begin and state != 'broken' :
                    if state not in ['before parts', 'between parts']:
                        print "Error: part begin found in state=\"%s\"" %(state,)
                        print "   line %d=\"%s\"" %(lineno,line)
                    self.PVT_flush_buffers()
                    if len(self.results)==0:
                        print "here"
                    state = self.results[-1].part_begin( state, part_begin )
                elif part_end and state != 'broken' :
                    if state not in ['in part']:
                        print "Error: part end found in state=\"%s\"" %(state,)
                        print "   line %d=\"%s\"" %(lineno,line)
                    self.PVT_flush_buffers()
                    state = self.results[-1].part_end( state, part_end )
                elif test_end and state != 'broken' :
                    #if (state not in ['between parts']) and not self.results[-1].exit_status :
                    #    print "Error: test end found in state=\"%s\"" %(state,)
                    #    print "   line %d=\"%s\"" %(lineno,line)                
                    if state in ['old compound begin']:
                        old_test_begin = _test_begin.search( "TEST_BEGIN -1 %s" %
                                                             (compound_name,))
                        compound_name=None
                        self.results.append( gts_result( self.invocation.symbolic_name,
                                                         self.scoreboard, self.get_type() ))
                        if len( self.results ) > 1:
                            state="between tests"
                        else:
                            state="before tests"
                        self.scoreboard.event['test_added'].publish(gantlet.events.test_added_event, 1)
                        self.results[-1].exit_status = self.exit_status
                        state = self.results[-1].test_begin( state, old_test_begin )
                        
                    self.PVT_flush_buffers()
                    if len( self.results ) == 0:
                        self.results.append( gts_result( self.invocation.symbolic_name, \
                                                         self.scoreboard, self.get_type() ))
                        self.results[-1].exit_status = self.exit_status
                        self.results[-1].broken("Missing Test Begin","syntax error")
                    state = self.results[-1].test_end( state, test_end )
                    compound_name = None
                else:  # some other kind of text
                    comment = _comment.search(line)
                    if comment:
                        if len( self.buffer ):
                            self.PVT_flush_buffers()
                        text_state = 'comment'
                        self.comment_buffer.append(comment.group('text'))
                    else:
                        if len( self.comment_buffer ):
                            self.PVT_flush_buffers()
                        text_state = ''
                        self.buffer.append(line)
	except Exception, details :
  	    print "Unexpected error:", sys.exc_info()[0]
	    print "                :", details

        if state == 'before tests' and len(self.results) == 0 and self.scoreboard.config.allow_exit_status_only :
            self.results.append( exit_status_result(  self.invocation.symbolic_name,
                                                  self.scoreboard, "exit_status", self.exit_status) )
        elif state != 'between tests' and state != 'broken':
            if len(self.results) == 0:
                self.results.append(gts_result( self.invocation.symbolic_name,
                                                self.scoreboard, self.get_type() ))
            self.results[-1].exit_status = self.exit_status
            self.results[-1].try_recover_premature_end( state )
        elif state == 'broken':
            self.results[-1].try_recover_premature_end( state )

    def PVT_flush_buffers( self ):
        if len( self.buffer ):
            s = string.join(self.buffer,"\n").strip()
            if len(s):
                self.scoreboard.event['text'].publish(gantlet.events.text_event, s)
            self.buffer = []
        elif len( self.comment_buffer ):
            s = string.join(self.comment_buffer,"\n")
            if len(s):
                self.scoreboard.event['comment'].publish(gantlet.events.comment_event, s)
            self.comment_buffer = []


def _test():
   # t = test('autoexec.bat',r'C:\autoexec.bat',r'C:\autoexec.bat')
   # print t.__dict__
   # 
   # t = test('winhelp.exe',r'C:\WINNT\winhelp.exe',r'C:\WINNT\winhelp.exe')
   # print t.__dict__
   # 
   # t2 = test("`test 2`",'test2', 'test2')
   # print t2.__dict__
   # 
   # t2 = test('foo','test',"`PETF_NAME=foo test 2`")
   # print t2.__dict__
   pass


if __name__ == '__main__':
    _test()



#! /usr/bin/env python
# Python setup.py to build sidl python support libraries
#
# Copyright (c) 2000-2003, Lawrence Livermore National Security, LLC
# Produced at the Lawrence Livermore National Laboratory.
# Written by the Components Team <components@llnl.gov>
# UCRL-CODE-2002-054
# All rights reserved.
# 
# This file is part of Babel. For more information, see
# http://www.llnl.gov/CASC/components/. Please read the COPYRIGHT file
# for Our Notice and the LICENSE file for the GNU Lesser General Public
# License.
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by
# the Free Software Foundation) version 2.1 dated February 1999.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
# conditions of the GNU Lesser General Public License for more details.
# 
# You should have recieved a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
from distutils.core import setup,Extension
from re import compile
import sys

inc_re = compile('^--include-dirs=(.*)$')
lib_re = compile('^--library-dirs=(.*)$')
exlib_re = compile('^--extra-library=(.*)$')
old_argv = sys.argv
sys.argv = []
inc_dirs = ['.']
lib_dirs = []
libs=['sidl']

for i in old_argv:
  m = inc_re.match(i)
  if (m):
    if (len(m.group(1))): inc_dirs.append(m.group(1))
  else:
    m = lib_re.match(i)
    if (m):
      if (len(m.group(1))): lib_dirs.append(m.group(1))
    else:
      m = exlib_re.match(i)
      if (m):
        if (len(m.group(1))): libs.append(m.group(1))
      else:
        sys.argv.append(i)
      
setup(name="llnl_babel",
      author="Tom Epperly",
      version="1.4.0",
      description="Build Python support extension modules for sidl",
      author_email="components@llnl.gov",
      url="http://www.llnl.gov/CASC/components/",
      include_dirs=inc_dirs,
      headers = ["sidlObjA.h", "sidlPyArrays.h", "sidlStruct.h" ],
      py_modules = [ 'sidlBaseException' ],
      ext_modules = [
    Extension('sidlObjA',
              ["sidlObjA.c"],
              library_dirs=lib_dirs,
              libraries=libs),
    Extension('sidlStruct',
              ["sidlStruct.c"],
              library_dirs=lib_dirs,
              libraries=libs),
    Extension('sidlPyArrays',
              ["sidlPyArrays.c"],
              library_dirs=lib_dirs,
              libraries=libs)])



#
# Copyright(c) 2001-2003, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# Written by Gary Kumfert <kumfert@llnl.gov>.
# UCRL-CODE-2002-043.
# All rights reserved.
#
# This file is part of Gantlet.  For details, see 
# http://www.llnl.gov/CASC/components/software.html or contact the author.
#
# Gantlet is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by 
# the Free Software Foundation) version 2.1 dated February 1999.
#
# Gantlet is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even IMPLIED WARRANTY OF MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the terms and conditions of
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this software; if not, write to the Free Software Foundation, 
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# ADDITIONAL NOTICE:
# 
# A. This notice is required to be provided under our contract with the
#    U.S. Department of Energy (DOE).  This work was produced at the 
#    University of California, Lawrence Livermore National Laboratory
#    under Contract No. W-7405-ENG-48 with the DOE.
#
# B. Neither the United States Government nor the University of California
#    nor any of their employees make any warranty, express or implied, or
#    assumes any liability or responsibility for the accuracy, completeness, 
#    or usefulness of any information, apparatus, product, or process 
#    disclosed, or represents that its use would not infringe on 
#    privately-owned rights.
# 
# C. Also, reference herein to any specific commercial products, process, or
#    services by trade name, trademark, manufacturer or otherwise does not
#    necessarily constitute or imply its endoresement, recommendation, or
#    favoring by the United States Government or the University of California.
#    The views and opinions of authors expressed herein do not necessarily 
#    state or reflect those of the United States Government or the University
#    of California, and shall not be used for advertising or product 
#    endorsement purposes.
"""
This class creates instances of test 
(or more precisely, children of test).
"""

#import re
import os
from gantlet.test_invocation import test_invocation
from gantlet.gts_tparser_exec import gts_tparser_exec
from gantlet.gts_tparser_script import gts_tparser_script, known_extensions
from gantlet.gts_tparser_read import gts_tparser_read
from gantlet.unknown_tparser import unknown_tparser
from gantlet.xml_tparser import xml_tparser, xml_extension

class tparser_factory:
    def __init__( self, args, scoreboard, srcdir = os.curdir):
	self.args        = args
	self.srcdir      = srcdir
	self.tests       = []
	for arg in self.args:
            test = self.create_test( arg, scoreboard )
            self.tests.append( test )

    def create_test( self, test_string, scoreboard ):
	"""
	test = create_test( test_string, scoreboard )

	creates an appropriate derived class inheriting from 
	gantlet.test for the given test_string
	"""

        invocation = test_invocation( test_string, self.srcdir, scoreboard )

	# now start checking the file system.
	if invocation.errmsgs:
	    return unknown_tparser( invocation, scoreboard )
        if invocation.is_command:
            return gts_tparser_exec( invocation, scoreboard )
        if os.access( invocation.filename, os.R_OK ):
            if xml_extension( invocation.extension ):
                return xml_tparser( invocation, scoreboard )
            elif invocation.extension in known_extensions.keys():
                return gts_tparser_script( invocation, scoreboard )
        if os.access( invocation.filename, os.X_OK ):
	    return gts_tparser_exec( invocation, scoreboard )
        elif os.access( invocation.filename, os.R_OK ):
            return gts_tparser_read( invocation, scoreboard )
        else:
            invocation.errmsgs.append( ("File not Readable","unreadable") )
            return unknown_tparser( invocation, scoreboard )

    def append_test( self, test_string ):
	self.tests.append( self.create_test( test_string ) )

    def get_tests( self ):
	return self.tests
